/*******************************************************************************
 * Copyright 2015 - 2019 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.mahoe.banks.bos.jobs;

import java.util.Arrays;

import de.frankmuenster.mahoe.banks.bos.BankOfScotland;
import de.frankmuenster.mahoe.banks.bos.web.BosWebAccountInformation;
import de.frankmuenster.mahoe.banks.bos.web.BosWebSite;
import de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszugPdf;
import de.frankmuenster.mahoe.jobs.InterfaceMahoeSynchronizeJob;
import de.frankmuenster.mahoe.utils.PasswdCache;
import de.frankmuenster.mahoe.web.WebSiteException;
import de.willuhn.util.ApplicationException;

/**
 * Job to download account statements from the Bank of Scotland.
 *
 * @author Frank Mnster
 */
public class BosSynchronizeJobKontoauszugPDF extends AbstractMahoeSynchronizeJobKontoauszugPdf<BosWebAccountInformation>
        implements InterfaceMahoeSynchronizeJob {

    /**
     * Standard constructor
     */
    public BosSynchronizeJobKontoauszugPDF() {

        super();
    }

    /**
     * @see de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszug#getWebSite()
     */
    @Override
    protected void getWebSite() throws WebSiteException, ApplicationException {

        this.webSite = BosWebSite.getInstance(this.konto);
    }

    @Override
    protected void login() throws WebSiteException, ApplicationException {

        final char[] password = PasswdCache.getPassword(BankOfScotland.NAME, this.kundennummer);
        try {
            this.webSite.login(password);
        } catch (final WebSiteException e) {
            // Passwort zurcksetzten
            PasswdCache.revoke(BankOfScotland.NAME, this.kundennummer);
            throw e;
        }
        Arrays.fill(password, ' ');
    }
}
