
package de.frankmuenster.mahoe.banks.bsh.assistant;

import org.apache.commons.lang.StringUtils;
import org.eclipse.swt.widgets.Composite;

import de.frankmuenster.mahoe.utils.I18N;
import de.willuhn.jameica.gui.Action;
import de.willuhn.jameica.gui.dialogs.AbstractDialog;
import de.willuhn.jameica.gui.input.TextInput;
import de.willuhn.jameica.gui.parts.ButtonArea;
import de.willuhn.jameica.gui.util.SimpleContainer;
import de.willuhn.jameica.system.OperationCanceledException;
import de.willuhn.util.ApplicationException;

/**
 * Der Start-Dialog zum Anlegen eines neues BSH Kontos. Fragt nur die KdNumme
 * rund das Passwort ab und ermittelt dann vorhandene Konten.
 *
 * @author Frank Mnster
 */
public class BshCreateKontoStartDialog extends AbstractDialog<String> {

    /**
     * Kundennummer Input
     */
    private transient TextInput kdNummerInput;

    /**
     * Kundennummer
     */
    private transient String kdNummer;

    /**
     *
     */
    public BshCreateKontoStartDialog() {
	super(AbstractDialog.POSITION_CENTER);
	this.setTitle(I18N.tr("dialogTitle")); //$NON-NLS-1$
	this.setSize(550, 400);
    }

    /**
     * @see de.willuhn.jameica.gui.dialogs.AbstractDialog#getData()
     */
    @Override
    protected String getData() {

	return this.kdNummer;
    }

    /**
     * @see de.willuhn.jameica.gui.dialogs.AbstractDialog#paint(org.eclipse.swt.widgets.Composite)
     */
    @Override
    protected void paint(final Composite parent) {

	// Erstelle einfachen Container
	final SimpleContainer container = new SimpleContainer(parent, true, 2);

	final String text = I18N.tr("BshCreateKontoStartDialog.explainText1") //$NON-NLS-1$
		+ I18N.tr("BshCreateKontoStartDialog.explainText2") //$NON-NLS-1$
		+ I18N.tr("BshCreateKontoStartDialog.startAssistentBtn") //$NON-NLS-1$
		+ I18N.tr("BshCreateKontoStartDialog.explainText3") //$NON-NLS-1$
		+ I18N.tr("BshCreateKontoStartDialog.explainText4") //$NON-NLS-1$
		+ I18N.tr("BshCreateKontoStartDialog.explainText5"); //$NON-NLS-1$
	this.kdNummerInput = new TextInput(StringUtils.EMPTY, 20, StringUtils.EMPTY);
	this.kdNummerInput.setMandatory(true);

	container.addText(text, true);
	container.addText(" ", true); //$NON-NLS-1$
	container.addLabelPair(I18N.tr("BshCreateKontoStartDialog.kdNumber"), this.kdNummerInput); //$NON-NLS-1$

	final ButtonArea buttons = new ButtonArea();
	buttons.addButton(I18N.tr("BshCreateKontoStartDialog.startAssistentBtn"), new Action() { //$NON-NLS-1$

	    /**
	     * @see de.willuhn.jameica.gui.Action#handleAction(java.lang.Object)
	     */
	    @Override
	    public void handleAction(final Object context) throws ApplicationException {

		BshCreateKontoStartDialog.this.kdNummer = (String) BshCreateKontoStartDialog.this.kdNummerInput
			.getValue();
		BshCreateKontoStartDialog.this.close();
	    }
	}, null, true, "document-save.png"); //$NON-NLS-1$
	// Abbrechen Button einfgen
	buttons.addButton(I18N.tr("BshCreateKontoStartDialog.cancelBtn"), new Action() { //$NON-NLS-1$

	    /**
	     * @see de.willuhn.jameica.gui.Action#handleAction(java.lang.Object)
	     */
	    @Override
	    public void handleAction(final Object context) throws ApplicationException {

		throw new OperationCanceledException();
	    }
	}, null, false, "process-stop.png"); //$NON-NLS-1$

	container.addButtonArea(buttons);
    }

}
