
package de.frankmuenster.mahoe.banks.bsh.json;

import java.math.BigDecimal;
import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

import de.frankmuenster.mahoe.banks.bsh.json.deserializer.SimpleMoneyDeserializer;

/**
 * JSON Freistellungsbetrag Objekt
 *
 * @author Frank Mnster
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({ "coreid", "usedamount", "anticipatedamount", "type", "suggestedamount", "recordedondate",
	"tariffamount", "validfromdate" })
public class Exemption {

    /**
     * Erwartete Zinsen
     */
    @JsonProperty("anticipatedamount")
    private BigDecimal anticipatedamount;

    /**
     * Haupt-Vertrag-ID
     */
    @JsonProperty("coreid")
    private String coreid;

    /**
     * Erfasst am
     */
    @JsonProperty("recordedondate")
    private Date recordedondate;

    /**
     * Vorgeschlagener Betrag
     */
    @JsonProperty("suggestedamount")
    private BigDecimal suggestedamount;

    /**
     * Erfasster Betrag
     */
    @JsonProperty("tariffamount")
    private BigDecimal tariffamount;

    /**
     * Freistellungstyp ???
     */
    @JsonProperty("type")
    private String type;

    /**
     * Verbrauchter Betrag
     */
    @JsonProperty("usedamount")
    private BigDecimal usedamount;

    /**
     * G&auml;ltig ab
     */
    @JsonProperty("validfromdate")
    private Date validfromdate;

    /**
     * Standardkonstruktor
     */
    public Exemption() {
	// Absichtlich leer
    }

    /**
     * Liefert die erwarteten Zinsen
     *
     * @return die erwarteten Zinsen
     */
    @JsonProperty("anticipatedamount")
    @JsonDeserialize(using = SimpleMoneyDeserializer.class)
    public BigDecimal getAnticipatedamount() {

	return this.anticipatedamount;
    }

    /**
     * Liefert die Vertagshaupt-ID
     *
     * @return die Vertagshaupt-ID
     */
    @JsonProperty("coreid")
    public String getCoreid() {

	return this.coreid;
    }

    /**
     * Liefert das Erfassungsdatum
     *
     * @return das Erfassungsdatum
     */
    @JsonProperty("recordedondate")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "dd.MM.yyyy", timezone = "CET")
    public Date getRecordedondate() {

	return this.recordedondate;
    }

    /**
     * Liefert den vorgeschlagenen Betrag
     *
     * @return den vorgeschlagenen Betrag
     */
    @JsonProperty("suggestedamount")
    @JsonDeserialize(using = SimpleMoneyDeserializer.class)
    public BigDecimal getSuggestedamount() {

	return this.suggestedamount;
    }

    /**
     * Liefert den erfassten Betrag
     *
     * @return den erfassten Betrag
     */
    @JsonProperty("tariffamount")
    @JsonDeserialize(using = SimpleMoneyDeserializer.class)
    public BigDecimal getTariffamount() {

	return this.tariffamount;
    }

    /**
     * Liefert den Freistellungstyp
     *
     * @return den Freistellungstyp
     */
    @JsonProperty("type")
    public String getType() {

	return this.type;
    }

    /**
     * Liefert den verbrauchten Betrag
     *
     * @return den verbrauchten Betrag
     */
    @JsonProperty("usedamount")
    @JsonDeserialize(using = SimpleMoneyDeserializer.class)
    public BigDecimal getUsedamount() {

	return this.usedamount;
    }

    /**
     * Liefert das Datum, ab dem der Freistellungsauftrag gltig ist
     *
     * @return das Datum, ab dem der Freistellungsauftrag gltig ist
     */
    @JsonProperty("validfromdate")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "dd.MM.yyyy", timezone = "CET")
    public Date getValidfromdate() {

	return this.validfromdate;
    }

}
