/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.banks.santander.web;

import java.io.IOException;
import java.rmi.RemoteException;
import java.util.Arrays;
import java.util.List;

import com.gargoylesoftware.htmlunit.FailingHttpStatusCodeException;
import com.gargoylesoftware.htmlunit.WebClient;
import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
import com.gargoylesoftware.htmlunit.html.HtmlForm;
import com.gargoylesoftware.htmlunit.html.HtmlInput;
import com.gargoylesoftware.htmlunit.html.HtmlOption;
import com.gargoylesoftware.htmlunit.html.HtmlPage;
import com.gargoylesoftware.htmlunit.html.HtmlSelect;

import de.frankmuenster.mahoe.MahoeSynchronizeBackend;
import de.frankmuenster.mahoe.banks.santander.web.AbstractSantanderWebSite.DocumentType;
import de.frankmuenster.mahoe.utils.PasswdCache;
import de.frankmuenster.mahoe.web.WebSite;
import de.frankmuenster.mahoe.web.WebSiteException;
import de.frankmuenster.mahoe.web.WebSiteExceptionTypes;
import de.willuhn.jameica.hbci.rmi.Konto;
import de.willuhn.logging.Logger;
import de.willuhn.util.ApplicationException;

/**
 * Utility class for Santander Web Site Object
 *
 * @author Frank Mnster
 *
 */
public final class SantanderWebSiteUtils {

    /**
     * Return the first message page filtered for all transactions sheets
     *
     * @param webClient
     *            the logged in webclient
     * @param documentType
     *            either
     *
     * @return the first message page
     * @throws FailingHttpStatusCodeException
     * @throws IOException
     */
    public static HtmlPage getDocumentFilteredPage(final WebClient webClient, final DocumentType documentType)
            throws FailingHttpStatusCodeException, IOException {

        HtmlPage filteredPage;
        HtmlPage postBoxPage = webClient.getPage(SantanderBankEnum.CONSUMER.getPostBoxUrl());
        final HtmlAnchor anchor = postBoxPage.getAnchorByText("Erweiterte Suche"); //$NON-NLS-1$
        postBoxPage = anchor.click();
        Logger.debug(postBoxPage.asText());
        Logger.debug(postBoxPage.asXml());
        final HtmlForm dataFilter = postBoxPage.getFormByName("formDataFilter"); //$NON-NLS-1$
        final List<HtmlInput> docStatus = dataFilter.getInputsByName("formDataFilter.status"); //$NON-NLS-1$
        for (final HtmlInput htmlInput : docStatus) {
            switch (htmlInput.getId()) {
            case "neue": //$NON-NLS-1$
            case "gelesene": //$NON-NLS-1$
                htmlInput.setChecked(false);
                break;
            case "alle": //$NON-NLS-1$
                htmlInput.setChecked(true);
                break;
            default:
                break;
            }
        }
        final HtmlSelect docType = dataFilter.getSelectByName("formDataFilter.documentType"); //$NON-NLS-1$
        final List<HtmlOption> options = docType.getOptions();
        for (final HtmlOption htmlOption : options) {
            htmlOption.setSelected(false);
            if (documentType.getValue().equals(htmlOption.getText())) {
                docType.setSelectedAttribute(htmlOption, true);
            }
        }
        final HtmlInput submit = dataFilter.getInputByValue("Suchen"); //$NON-NLS-1$
        filteredPage = submit.click();
        Logger.debug(filteredPage.asText());
        Logger.debug(filteredPage.asXml());
        return filteredPage;
    }

    /**
     * Login the user with konto on the given website object
     *
     * @param webSite
     *            the website object on which the login should be performed
     * @param konto
     *            the account to use to login
     * @param kundennummer
     *            the user identification to use
     *
     * @throws WebSiteException
     * @throws ApplicationException
     */
    public static void login(final WebSite<?> webSite, final Konto konto, final String kundennummer)
            throws WebSiteException, ApplicationException {

        String bankName;
        try {
            bankName = konto.getMeta(MahoeSynchronizeBackend.BANK_NAME, SantanderBankEnum.CONSUMER.getIdString());
            bankName = "Santander " + SantanderBankEnum.find(bankName).getBankName(); //$NON-NLS-1$
        } catch (final RemoteException e) {
            throw new ApplicationException(e);
        }
        final char[] password = PasswdCache.getPassword(bankName, kundennummer);
        try {
            webSite.login(password);
        } catch (final WebSiteException e) {
            if (e.getType().equals(WebSiteExceptionTypes.LOGIN_FAILED)
                    || e.getType().equals(WebSiteExceptionTypes.LOGIN_ERROR)) {
                // Passwort zurcksetzen
                PasswdCache.revoke(bankName, kundennummer);
            }
            throw e;
        }
        Arrays.fill(password, ' ');
    }

    /**
     * Private constructor for utility class
     */
    private SantanderWebSiteUtils() {
        // intentionally left blank
    }

}
