/*******************************************************************************
 * Copyright 2015 - 2019 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.banks.targobank.jobs;

import java.util.Arrays;

import de.frankmuenster.mahoe.banks.targobank.TargoBank;
import de.frankmuenster.mahoe.banks.targobank.web.TargoBankWebAccountInformation;
import de.frankmuenster.mahoe.banks.targobank.web.TargoBankWebSite;
import de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszugPdf;
import de.frankmuenster.mahoe.jobs.InterfaceMahoeSynchronizeJob;
import de.frankmuenster.mahoe.utils.PasswdCache;
import de.frankmuenster.mahoe.web.WebSiteException;
import de.frankmuenster.mahoe.web.WebSiteExceptionTypes;
import de.willuhn.util.ApplicationException;

/**
 * Job to download account statements from the Targo Bank.
 *
 * @author Frank Mnster
 */
public class TargoBankSynchronizeJobKontoauszugPDF
        extends AbstractMahoeSynchronizeJobKontoauszugPdf<TargoBankWebAccountInformation>
        implements InterfaceMahoeSynchronizeJob {

    /**
     * Standard constructor
     */
    public TargoBankSynchronizeJobKontoauszugPDF() {

        super();
    }

    /**
     * @see de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszug#getWebSite()
     */
    @Override
    protected void getWebSite() throws WebSiteException, ApplicationException {

        // get the instance of the TargoBankWebSite
        this.webSite = TargoBankWebSite.getInstance(this.konto);
    }

    /**
     * @see de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszugPdf#login()
     */
    @Override
    protected void login() throws WebSiteException, ApplicationException {

        // Read password from cache or user input
        final char[] password = PasswdCache.getPassword(TargoBank.NAME, this.kundennummer);

        try {
            // Login to web page
            this.webSite.login(password);
        } catch (final WebSiteException e) {
            if (e.getType().equals(WebSiteExceptionTypes.LOGIN_FAILED)) {
                // Passwort zurcksetzten
                PasswdCache.revoke(TargoBank.NAME, this.kundennummer);
            }
            throw e;
        }
        // Clear password array
        Arrays.fill(password, ' ');
    }

}
